Daft User Guide
===============

.. toctree::
    :hidden:
    :maxdepth: 1

    basic_concepts
    read-and-write
    expressions
    datatypes
    dataframe-operations
    sql
    aggregations
    udf
    poweruser
    integrations
    tutorials
    fotw/index

Welcome to **Daft**!

This user guide aims to help Daft users master the usage of the Daft for all your data needs.

.. NOTE::

    Looking to get started with Daft ASAP?

    The Daft User Guide is a useful resource to take deeper dives into specific Daft concepts, but if you are ready to jump into
    code you may wish to take a look at these resources:

    1. :doc:`../10-min`: Itching to run some Daft code? Hit the ground running with our 10 minute quickstart notebook.
    2. :doc:`../api_docs/index`: Searchable documentation and reference material to Daft's public API.

Table of Contents
-----------------

The Daft User Guide is laid out as follows:

:doc:`Basic Concepts <basic_concepts>`
**************************************

High-level overview of Daft interfaces and usage to give you a better understanding of how Daft will fit into your day-to-day workflow.

Daft in Depth
*************

Core Daft concepts all Daft users will find useful to understand deeply.

* :doc:`read-and-write`
* :doc:`expressions`
* :doc:`datatypes`
* :doc:`dataframe-operations`
* :doc:`aggregations`
* :doc:`udf`

:doc:`Structured Query Language (SQL) <sql>`
********************************************

A look into Daft's SQL interface and how it complements Daft's Pythonic DataFrame APIs.

:doc:`The Daft Poweruser <poweruser>`
*************************************

Become a true Daft Poweruser! This section explores advanced topics to help you configure Daft for specific application environments, improve reliability and optimize for performance.

:doc:`Integrations <integrations>`
**********************************

Learn how to use Daft's integrations with other technologies such as Ray Datasets or Apache Iceberg.

:doc:`Tutorials <tutorials>`
****************************

Applications built using Daft to serve as inspiration for your own projects
